;; See the License.txt file for information on the licensing of this
;; software.(module
(module
 chez-interface ()
 (import itunes-songlist-converter)
 (define mainwin
   (create <toplevel> with
	   (title: "itsl->html")
	   (border-width: 10)
	   (resizable: #f #f)))
 (define ifileframe
   (create <frame> mainwin))
 (define ifilelbl
   (create <label> ifileframe with
	   (title: "iTunes XML Song List: ")))
 (define ifilefld
   (create <entry> ifileframe))
 (define ifilebut
   (create <button> ifileframe with
	   (title: "Browse")
	   (action: (lambda (self)
		      (let ((filename (swl:file-dialog
				       "Select iTunes Song List"
				       'open
				       (file-types: '(("iTunes XML Song List"
						       ("*.xml"))))
				       (parent: mainwin))))
			(when filename
			      (delete-all ifilefld)
			      (insert-at ifilefld 0 filename)))))))
 (define ofileframe
   (create <frame> mainwin))
 (define ofilelbl
   (create <label> ofileframe with
	   (title: "Output to: ")))
 (define ofilefld
   (create <entry> ofileframe with))
 (define ofilebut
   (create <button> ofileframe with
	   (title: "Browse")
	   (action: (lambda (self)
		      (let ((filename (swl:file-dialog
				       "Enter File to Write to"
				       'save
				       (file-types: '(("HTML Files"
						       ("*.html"))))
				       (parent: mainwin))))
			(when filename
			      (delete-all ofilefld)
			      (insert-at ofilefld 0 filename)))))))
 (define lblframe
   (create <frame> mainwin with))
 (define availlbl
   (create <label> lblframe with
	   (title: "Available Fields:")))
 (define currntlbl
   (create <label> lblframe with
	   (title: "Currently Selected Fields:")))
 (define listframe
   (create <frame> mainwin))
 (define inlist
   (create <listbox> listframe with
	   (vscroll-notify: (lambda (up down)
			      (set-view! inlistscroll up down)))))
 (define inlistscroll
   (create <scrollbar> listframe with
	   (orientation: 'vertical)
	   (action: (lambda (self n q)
		      (vscroll inlist n q)))))
 (define listbutframe
   (create <frame> mainwin with
	   (border-width: 5)))
 (define insertbut
   (create <button> listbutframe with
	   (title: ">>")
	   (action: (lambda (self)
		      (let ((items (get-selected-items inlist)))
			(when items
			      (if (list? items)
				  (let loop ((items items))
				    (if (not (null? items))
					(begin
					  (insert olist
						  (+ (item-count olist)
						     1)
						  (get-item
						   inlist
						   (car items)))
					  (loop (cdr items)))))
				  (insert olist (+ (item-count olist)
						   1)
					  (get-item inlist items)))))))))

 (define removebut
   (create <button> listbutframe with
	   (title: "<<")
	   (action: (lambda (self)
		      (let ((items (get-selected-items olist)))
			(when items
			      (if (list? items)
				  (let loop ((items items))
				    (if (not (null? items))
					(begin (delete olist (car items))
					       (loop (cdr items)))))
				  (delete olist items))))))))
 (define olist
   (create <listbox> listframe with
	   (vscroll-notify: (lambda (up down)
			      (set-view! olistscroll up down)))))
 (define olistscroll
   (create <scrollbar> listframe with
	   (orientation: 'vertical)
	   (action: (lambda (self n q)
		      (vscroll olist n q)))))
 (define buttonframe
   (create <frame> mainwin))
 (define cancbut
   (create <button> buttonframe with
	   (title: "Quit")
	   (action: (lambda (self)
		      (swl:end-application 'exit-all)))))
 (define (get-field-list olist)
   (let ((n (item-count olist)))
     (let loop ((i 0)
		(fl (list)))
       (if (> i n)
	   fl
	   (loop (+ i 1)
		 (append fl (list (string->symbol (get-item olist i)))))))))
 (define okaybut
   (create <button> buttonframe with
	   (title: "Process File")
	   (action: (lambda (self)
		      (let ((ifile (get-string ifilefld))
			    (ofile (get-string ofilefld))
			    (flist (get-field-list olist)))
			(if (and (not (string=? ifile ""))
				 (not (string=? ofile ""))
				 (not (null? flist)))
			    (itsl->html ifile ofile flist)))))))
 (insert inlist 0 "Track ID" "Name" "Artist" "Album" "Genre" "Kind"
	 "Size" "Total Time" "Disc Number" "Disc Count" "Track Number" "Track
Count" "Year" "Date Modified" "Date Added" "Bit Rate" "Sample Rate"
"Play Count" "Play Date" "Play Date UTC" "Rating" "Persistent ID"
"Track Type" "Location" "File Folder Count" "Library Folder Count")
 (pack ifileframe
       (fill: 'x))
 (pack ifilelbl
       (side: 'left)
       (fill: 'x))
 (pack ifilebut
       (side: 'right))
 (pack ifilefld
       (side: 'right)
       (fill: 'x))
 (pack ofileframe
       (fill: 'x))
 (pack ofilelbl
       (side: 'left)
       (fill: 'x))
 (pack ofilebut
       (side: 'right))
 (pack ofilefld
       (side: 'right)
       (fill: 'x))
 (pack lblframe
       (fill: 'x))
 (pack availlbl
       (side: 'left))
 (pack currntlbl
       (side: 'right))
 (pack listframe
       (fill: 'x))
 (pack inlist
       (side: 'left)
       (fill: 'both))
 (pack inlistscroll
       (side: 'left)
       (fill: 'y))
 (pack olistscroll
       (side: 'right)
       (fill: 'y))
 (pack olist
       (side: 'right)
       (fill: 'both))
 (pack listbutframe
       (side: 'top)
       (anchor: 'center))
 (pack removebut
       (side: 'left))
 (pack insertbut
       (side: 'left))
 (pack buttonframe
       (side: 'bottom))
 (pack cancbut
       (side: 'right))
 (pack okaybut
       (side: 'right)))


